@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::POE;
-$Acme::CPANAuthors::POE::VERSION = '0.78';
+$Acme::CPANAuthors::POE::VERSION = '0.80';
 #ABSTRACT: We are CPAN Authors of POE
 
 use strict;
@@ -14,10 +14,12 @@ use Acme::CPANAuthors::Register (
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
   AJCT => q[Adam Taylor],
+  ALTREUS => q[Alastair Douglas],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
   AVENJ => q[Jon Portnoy],
+  BARBIE => q[Barbie],
   BEVO => q[Brendan Beveridge],
   BIGPRESH => q[David Precious],
   BINGOS => q[Chris Williams],
@@ -48,6 +50,7 @@ use Acme::CPANAuthors::Register (
   EDOARDO => q[Edoardo Sabadelli],
   ERIAM => q[Eriam Schaffter],
   ESTRAI => q[Daniel (Estrai) Lukasiak],
+  ETHER => q[Karen Etheridge],
   EWATERS => q[Eric Waters],
   FLETCH => q[Mike Fletcher],
   FRANCKC => q[Franck Cuny],
@@ -56,7 +59,6 @@ use Acme::CPANAuthors::Register (
   GETTY => q[Torsten Raudssus],
   GRAYKOT => q[Sergey Kotenko],
   GREGFAST => q[Greg Fast],
-  GRODITI => q[Guillermo Roditi],
   GVL => q[Gelu Lupas],
   GWYN => q[Philip Gwyn],
   HACHI => q[Jonathan Steinert],
@@ -65,8 +67,9 @@ use Acme::CPANAuthors::Register (
   HEYTRAV => q[William Travis Holton],
   HINRIK => q[Hinrik Orn Sigurdsson],
   IDERRICK => q[Olivier Schwander],
-  INFIDEL => q[Jason McManus],
+  INFIDEL => q[],
   IRONCAMEL => q[Naveed Massjouni],
+  ISHIGAKI => q[Kenichi Ishigaki],
   IVORW => q[Ivor Williams],
   JBISBEE => q[Jeff Bisbee],
   JGOFF => q[Jeff Goff],
@@ -83,6 +86,8 @@ use Acme::CPANAuthors::Register (
   KITANO => q[dann],
   KIXX => q[Christian-Rolf Gruen],
   LOSYME => q[Loic TROCHET],
+  MAF => q[Mark Flickinger],
+  MAFF => q[Matthew Connelly],
   MAHEX => q[Mark A. Hershberger],
   MARTIJN => q[Martijn van Beers],
   MCHING => q[Michael Ching],
@@ -94,7 +99,7 @@ use Acme::CPANAuthors::Register (
   MIKI => q[Takeshi Miki],
   MISCHKE => q[Mark McConnell],
   MIYAGAWA => q[Tatsuhiko Miyagawa],
-  MLEHMANN => q[Marc Lehmann],
+  MLEHMANN => q[Marc A. Lehmann],
   MMIMS => q[Marc Mims],
   MMORGAN => q[Mark Morgan],
   MNUNBERG => q[Mark Nunberg],
@@ -105,9 +110,9 @@ use Acme::CPANAuthors::Register (
   MRPERSON => q[Curtis Hawthorne],
   MSCHILLI => q[Michael Schilli],
   MSERGEANT => q[MSERGEANT],
-  MSTROUT => q[Matt S Trout],
   NPEREZ => q[Nicholas Perez],
   NUFFIN => q[Yuval Kogman],
+  OALDERS => q[Olaf Alders],
   OMNI => q[Michael Alexander],
   PAULV => q[Paul Visscher],
   PEVANS => q[Paul Evans],
@@ -125,6 +130,7 @@ use Acme::CPANAuthors::Register (
   RJBS => q[Ricardo SIGNES],
   RJP => q[Rob Partington],
   RKITOVER => q[Rafael Kitover],
+  RRWO => q[Robert Rothenberg],
   SABECK => q[Scott Beck],
   SAPER => q[Sebastien Aperghis-Tramoni],
   SCILLEY => q[Scott Cilley],
@@ -138,7 +144,7 @@ use Acme::CPANAuthors::Register (
   STE => q[Steve James],
   SUNGO => q[sungo],
   SUZUKI => q[Yuji Suzuki],
-  TAG => q[Scott McCoy],
+  TAG => q[Scott S. McCoy],
   TBR => q[Thiago Berlitz Rondon],
   TEEJAY => q[Aaron James Trevena],
   TONYC => q[Tony Cook],
@@ -171,7 +177,7 @@ Acme::CPANAuthors::POE - We are CPAN Authors of POE
 
 =head1 VERSION
 
-version 0.78
+version 0.80
 
 =head1 SYNOPSIS
 
@@ -202,10 +208,12 @@ It is currently statically generated information, I hope to make it dynamic in t
   AHOYING => q[Andrew Hoying],
   AIMASS => q[Alejandro Imass],
   AJCT => q[Adam Taylor],
+  ALTREUS => q[Alastair Douglas],
   ANDYPUR => q[Andrew V. Purshottam],
   APOCAL => q[Apocalypse],
   ARCANEZ => q[Justin Hunter],
   AVENJ => q[Jon Portnoy],
+  BARBIE => q[Barbie],
   BEVO => q[Brendan Beveridge],
   BIGPRESH => q[David Precious],
   BINGOS => q[Chris Williams],
@@ -236,6 +244,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   EDOARDO => q[Edoardo Sabadelli],
   ERIAM => q[Eriam Schaffter],
   ESTRAI => q[Daniel (Estrai) Lukasiak],
+  ETHER => q[Karen Etheridge],
   EWATERS => q[Eric Waters],
   FLETCH => q[Mike Fletcher],
   FRANCKC => q[Franck Cuny],
@@ -244,7 +253,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   GETTY => q[Torsten Raudssus],
   GRAYKOT => q[Sergey Kotenko],
   GREGFAST => q[Greg Fast],
-  GRODITI => q[Guillermo Roditi],
   GVL => q[Gelu Lupas],
   GWYN => q[Philip Gwyn],
   HACHI => q[Jonathan Steinert],
@@ -253,8 +261,9 @@ It is currently statically generated information, I hope to make it dynamic in t
   HEYTRAV => q[William Travis Holton],
   HINRIK => q[Hinrik Orn Sigurdsson],
   IDERRICK => q[Olivier Schwander],
-  INFIDEL => q[Jason McManus],
+  INFIDEL => q[],
   IRONCAMEL => q[Naveed Massjouni],
+  ISHIGAKI => q[Kenichi Ishigaki],
   IVORW => q[Ivor Williams],
   JBISBEE => q[Jeff Bisbee],
   JGOFF => q[Jeff Goff],
@@ -271,6 +280,8 @@ It is currently statically generated information, I hope to make it dynamic in t
   KITANO => q[dann],
   KIXX => q[Christian-Rolf Gruen],
   LOSYME => q[Loic TROCHET],
+  MAF => q[Mark Flickinger],
+  MAFF => q[Matthew Connelly],
   MAHEX => q[Mark A. Hershberger],
   MARTIJN => q[Martijn van Beers],
   MCHING => q[Michael Ching],
@@ -282,7 +293,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   MIKI => q[Takeshi Miki],
   MISCHKE => q[Mark McConnell],
   MIYAGAWA => q[Tatsuhiko Miyagawa],
-  MLEHMANN => q[Marc Lehmann],
+  MLEHMANN => q[Marc A. Lehmann],
   MMIMS => q[Marc Mims],
   MMORGAN => q[Mark Morgan],
   MNUNBERG => q[Mark Nunberg],
@@ -293,9 +304,9 @@ It is currently statically generated information, I hope to make it dynamic in t
   MRPERSON => q[Curtis Hawthorne],
   MSCHILLI => q[Michael Schilli],
   MSERGEANT => q[MSERGEANT],
-  MSTROUT => q[Matt S Trout],
   NPEREZ => q[Nicholas Perez],
   NUFFIN => q[Yuval Kogman],
+  OALDERS => q[Olaf Alders],
   OMNI => q[Michael Alexander],
   PAULV => q[Paul Visscher],
   PEVANS => q[Paul Evans],
@@ -313,6 +324,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   RJBS => q[Ricardo SIGNES],
   RJP => q[Rob Partington],
   RKITOVER => q[Rafael Kitover],
+  RRWO => q[Robert Rothenberg],
   SABECK => q[Scott Beck],
   SAPER => q[Sebastien Aperghis-Tramoni],
   SCILLEY => q[Scott Cilley],
@@ -326,7 +338,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   STE => q[Steve James],
   SUNGO => q[sungo],
   SUZUKI => q[Yuji Suzuki],
-  TAG => q[Scott McCoy],
+  TAG => q[Scott S. McCoy],
   TBR => q[Thiago Berlitz Rondon],
   TEEJAY => q[Aaron James Trevena],
   TONYC => q[Tony Cook],
